#include <stdio.h>

extern int yylex();
extern FILE *yyin;
extern int yyrestart(FILE*);

int main (int argc, char *argv[])
{
  int parser_status, error;

  /********************************************************/
  /** Check command line arguments **/
  /********************************************************/

  if (argc != 2)
  {
    fprintf (stderr, "\nUsage: %s config_file\n", argv[0]);
    return 1;
  }

  /********************************************************/
  /** Open file for the flex parser **/
  /********************************************************/

  yyin = fopen (argv[1], "r");
  if (yyin == NULL)
  {
    fprintf (stderr, "\nCan not open file %s\n", argv[1]);
    return 1;
  }

  /********************************************************/
  /** Call the flex parser using 'yyin' as input */
  /********************************************************/

  parser_status = yylex();
  fclose (yyin);

  switch (parser_status)
  {
    case 0: {
              fprintf (stdout, "\n-- OK --\n");
              error = 0; }; break;
    case 1: {
              fprintf (stderr, "Internal parser error");
              error = 1; }; break;
    default:{
              fprintf (stderr, "Internal error (unexpected return value from the parser)");
              error = 3; };
  }

  /********************************************************/
  /** Try with another file ... */
  /********************************************************/

  yyin = fopen (argv[1], "r");
  if (yyin == NULL)
  {
    fprintf (stderr, "\nCan not open file %s\n", argv[1]);
    return 1;
  }

  yyrestart(yyin);

  parser_status = yylex();
  fclose (yyin);

  switch (parser_status)
  {
    case 0: {
              fprintf (stdout, "\n-- OK --\n");
              error = 0; }; break;
    case 1: {
              fprintf (stderr, "Internal parser error");
              error = 1; }; break;
    default:{
              fprintf (stderr, "Internal error (unexpected return value from the parser)");
              error = 3; };
  }

  return error;
}
